pub struct Chat<CP, Output = Unstructured> { /* private fields */ }Implementations
Sourceimpl<CP: CompletionProvider> Chat<CP, Unstructured>
impl<CP: CompletionProvider> Chat<CP, Unstructured>
Sourcepub async fn complete(
&mut self,
messages: &mut Messages,
) -> Result<ChatOutcome<ChatResponse>, ChatFailure>
pub async fn complete( &mut self, messages: &mut Messages, ) -> Result<ChatOutcome<ChatResponse>, ChatFailure>
Run the chat loop until the model completes, max_steps is reached,
or a tool call strategy pauses execution (pending approval,
scheduled, etc). Callers handle ChatOutcome::Paused by mutating
pending tool statuses and invoking Chat::resume.
Sourcepub async fn resume(
&mut self,
messages: &mut Messages,
) -> Result<ChatOutcome<ChatResponse>, ChatFailure>
pub async fn resume( &mut self, messages: &mut Messages, ) -> Result<ChatOutcome<ChatResponse>, ChatFailure>
Resume a loop that previously returned ChatOutcome::Paused. The
caller is expected to have resolved at least one pending tool
(typically by calling tool.approve(...) or tool.reject(...)
on each) before calling resume.
Sourceimpl<CP: CompletionProvider, T> Chat<CP, Structured<T>>where
T: DeserializeOwned + JsonSchema,
impl<CP: CompletionProvider, T> Chat<CP, Structured<T>>where
T: DeserializeOwned + JsonSchema,
pub async fn complete( &mut self, messages: &mut Messages, ) -> Result<ChatOutcome<StructuredResponse<T>>, ChatFailure>
Sourceimpl<CP: EmbeddingsProvider> Chat<CP, Embedded>
impl<CP: EmbeddingsProvider> Chat<CP, Embedded>
pub async fn embed( &mut self, messages: &mut Messages, ) -> Result<EmbeddingsResponse, ChatFailure>