pub fn build<N: NetworkNode>(
node: N,
storage: SqliteStorage,
) -> (ChatCoordinatorHandle, Receiver<CoordinatorEvent>, CoordinatorLoop<N>)Expand description
Build the coordinator and return a handle, event receiver, and the loop future.
pub fn build<N: NetworkNode>(
node: N,
storage: SqliteStorage,
) -> (ChatCoordinatorHandle, Receiver<CoordinatorEvent>, CoordinatorLoop<N>)Build the coordinator and return a handle, event receiver, and the loop future.