pub async fn emit_messages_state(
state: &mut CoordinatorState,
event_tx: &Sender<CoordinatorEvent>,
)Expand description
Emit the current message list without blocking on a full broadcast channel.
pub async fn emit_messages_state(
state: &mut CoordinatorState,
event_tx: &Sender<CoordinatorEvent>,
)Emit the current message list without blocking on a full broadcast channel.