addr_has_transport

Function addr_has_transport 

pub fn addr_has_transport(addr: &str) -> bool
Whether a multiaddr string contains at least one transport protocol. Used to reject bare /p2p/<peer_id> addresses that have no value for display or dialing.