SyncScheduler

Struct SyncScheduler 

pub struct SyncScheduler {
    pub sync_neighbors: Vec<PeerId>,
    pub available_peers: Vec<PeerId>,
    pub sync_heap: BinaryHeap<SyncEntry>,
}

Fields

sync_neighbors: Vec<PeerId>available_peers: Vec<PeerId>sync_heap: BinaryHeap<SyncEntry>

Implementations

Source

impl SyncScheduler

pub fn new() -> Self

pub fn schedule(&mut self, peer_id: &PeerId)

pub fn add_peer(&mut self, peer_id: &PeerId)

pub fn remove_peer(&mut self, peer_id: &PeerId)

pub fn replenish(&mut self)

pub fn next_due_delay(&self, now: Instant) -> Option<Duration>

pub fn pop_due( &mut self, now: Instant, room_peers: &HashSet<PeerId>, ) -> Vec<PeerId>

Pop all due sync entries, validate they are still neighbors and in the room, reschedule valid ones, and return the list of peers to sync with.